@@ -592,9 +592,7 @@ class Lock:
             self.details                            # noqa: B018
         except NotLockedError:
             log.error(
-                "lockfile exists but isn't safe to break: {}".format(
-                    self._lockfile
-                )
+                f"lockfile exists but isn't safe to break: {self._lockfile}"
             )
             return
         # Touch the lock file.  This reduces but does not eliminate the
